==> jc-1.4.0.tar.gz: polyglot/visit/FlowGraph__24Peer.h <==
// public class polyglot.visit.FlowGraph$Peer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d12d97b39a3d4675 polyglot_visit_FlowGraph__24Peer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24Peer_H_
#define _JC_polyglot_visit_FlowGraph__24Peer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_visit_DataFlow__24Item$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$sub_refs	_jc_polyglot_visit_FlowGraph__24Peer$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$refs	_jc_polyglot_visit_FlowGraph__24Peer$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$nonrefs	_jc_polyglot_visit_FlowGraph__24Peer$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$object	_jc_polyglot_visit_FlowGraph__24Peer$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24Peer$vmethods	_jc_polyglot_visit_FlowGraph__24Peer$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24Peer$vtable	_jc_polyglot_visit_FlowGraph__24Peer$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24Peer$vtype	_jc_polyglot_visit_FlowGraph__24Peer$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24Peer$method$_init$59effcea3622a14c(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$node$30a7b190eb74b1b6(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$preds$916d56f3bea2b404(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$succEdgeKeys$85ea033ea300061f(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$succs$a719b7d6facea149(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24Peer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$node$30a7b190eb74b1b6;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$preds$916d56f3bea2b404;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$succEdgeKeys$85ea033ea300061f;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$succs$a719b7d6facea149;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24Peer$vmethods {
	struct _jc_object	*(*node$30a7b190eb74b1b6)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
	struct _jc_object	*(*preds$916d56f3bea2b404)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
	struct _jc_object	*(*succEdgeKeys$85ea033ea300061f)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
	struct _jc_object	*(*succs$a719b7d6facea149)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24Peer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24Peer$vmethods	polyglot_visit_FlowGraph__24Peer;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24Peer$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24Peer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Peer$sub_refs {
	struct _jc_polyglot_visit_DataFlow__24Item$object	*inItem;
	struct _jc_object	*outItems;
	struct _jc_object	*node;
	struct _jc_object	*succs;
	struct _jc_object	*preds;
	struct _jc_object	*path__5fto__5ffinally;
	struct _jc_object	*succEdgeKeys;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Peer$refs {
    _jc_polyglot_visit_FlowGraph__24Peer$sub_refs	polyglot_visit_FlowGraph__24Peer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Peer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs	polyglot_visit_FlowGraph__24Peer;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24Peer$object {
	_jc_polyglot_visit_FlowGraph__24Peer$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24Peer$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24Peer$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24Peer$vtype _jc_polyglot_visit_FlowGraph__24Peer$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24Peer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24Peer$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24Peer_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/FlowGraph__24Peer.h <==
// public class polyglot.visit.FlowGraph$Peer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d12d97b39a3d4675 polyglot_visit_FlowGraph__24Peer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24Peer_H_
#define _JC_polyglot_visit_FlowGraph__24Peer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_visit_DataFlow__24Item$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$sub_refs	_jc_polyglot_visit_FlowGraph__24Peer$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$refs	_jc_polyglot_visit_FlowGraph__24Peer$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$nonrefs	_jc_polyglot_visit_FlowGraph__24Peer$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Peer$object	_jc_polyglot_visit_FlowGraph__24Peer$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24Peer$vmethods	_jc_polyglot_visit_FlowGraph__24Peer$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24Peer$vtable	_jc_polyglot_visit_FlowGraph__24Peer$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24Peer$vtype	_jc_polyglot_visit_FlowGraph__24Peer$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24Peer$method$_init$59effcea3622a14c(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$node$30a7b190eb74b1b6(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$preds$916d56f3bea2b404(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$succEdgeKeys$85ea033ea300061f(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24Peer$method$succs$a719b7d6facea149(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24Peer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$node$30a7b190eb74b1b6;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$preds$916d56f3bea2b404;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$succEdgeKeys$85ea033ea300061f;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$succs$a719b7d6facea149;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Peer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24Peer$vmethods {
	struct _jc_object	*(*node$30a7b190eb74b1b6)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*preds$916d56f3bea2b404)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*succEdgeKeys$85ea033ea300061f)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*succs$a719b7d6facea149)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24Peer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24Peer$vmethods	polyglot_visit_FlowGraph__24Peer;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24Peer$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24Peer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Peer$sub_refs {
	struct _jc_polyglot_visit_DataFlow__24Item$object	*inItem;
	struct _jc_object	*outItems;
	struct _jc_object	*node;
	struct _jc_object	*succs;
	struct _jc_object	*preds;
	struct _jc_object	*path__5fto__5ffinally;
	struct _jc_object	*succEdgeKeys;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Peer$refs {
    _jc_polyglot_visit_FlowGraph__24Peer$sub_refs	polyglot_visit_FlowGraph__24Peer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Peer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24Peer$sub_nonrefs	polyglot_visit_FlowGraph__24Peer;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24Peer$object {
	_jc_polyglot_visit_FlowGraph__24Peer$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24Peer$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24Peer$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24Peer$vtype _jc_polyglot_visit_FlowGraph__24Peer$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24Peer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24Peer$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24Peer_H_ */
